UpperHex

Trait UpperHex 

1.36.0 · Source
pub trait UpperHex {
    // Required method
    fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>;
}
X formatting.

The UpperHex trait should format its output as a number in hexadecimal, with A through F in upper case.

For primitive signed integers (i8 to i128, and isize), negative values are formatted as the two’s complement representation.

The alternate flag, #, adds a 0x in front of the output.

For more information on formatters, see the module-level documentation.

Examples

Basic usage with i32:

let y = 42; // 42 is '2A' in hex

assert_eq!(format!("{y:X}"), "2A");
assert_eq!(format!("{y:#X}"), "0x2A");

assert_eq!(format!("{:X}", -16), "FFFFFFF0");

Implementing UpperHex on a type:

use std::fmt;

struct Length(i32);

impl fmt::UpperHex for Length {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        let val = self.0;

        fmt::UpperHex::fmt(&val, f) // delegate to i32's implementation
    }
}

let l = Length(i32::MAX);

assert_eq!(format!("l as hex is: {l:X}"), "l as hex is: 7FFFFFFF");

assert_eq!(format!("l as hex is: {l:#010X}"), "l as hex is: 0x7FFFFFFF");

Required Methods

1.0.0 · Source

fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Formats the value using the given formatter.

Errors

This function should return Err if, and only if, the provided Formatter returns Err. String formatting is considered an infallible operation; this function only returns a Result because writing to the underlying stream might fail and it must provide a way to propagate the fact that an error has occurred back up the stack.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors



impl UpperHex for AccessMode



impl UpperHex for Bytes



impl UpperHex for BytesMut



impl UpperHex for FileModeInformation



impl UpperHex for Flags



impl UpperHex for GUID

example: 0000000000000000C000000000000046

Source

impl UpperHex for OpCodeFlag



impl UpperHex for PollFlags



impl UpperHex for RecvFlags



impl UpperHex for ReturnFlags



impl UpperHex for SendFlags



impl UpperHex for ShareMode



impl UpperHex for SocketFlags

Source

impl UpperHex for bf16

Available on non-SPIR-V only.
Source

impl UpperHex for f16

Available on non-SPIR-V only.
1.0.0 · Source

impl UpperHex for i8

1.0.0 · Source

impl UpperHex for i16

1.0.0 · Source

impl UpperHex for i32

1.0.0 · Source

impl UpperHex for i64

1.0.0 · Source

impl UpperHex for i128

1.0.0 · Source

impl UpperHex for isize

1.0.0 · Source

impl UpperHex for u8

1.0.0 · Source

impl UpperHex for u16

1.0.0 · Source

impl UpperHex for u32

1.0.0 · Source

impl UpperHex for u64

1.0.0 · Source

impl UpperHex for u128

1.0.0 · Source

impl UpperHex for usize



impl<'a, I> UpperHex for Format<'a, I>
where I: Iterator, <I as Iterator>::Item: UpperHex,



impl<'s, T> UpperHex for SliceVec<'s, T>
where T: UpperHex,



impl<A> UpperHex for ArrayVec<A>
where A: Array, <A as Array>::Item: UpperHex,



impl<A> UpperHex for TinyVec<A>
where A: Array, <A as Array>::Item: UpperHex,

Source

impl<L, R> UpperHex for Either<L, R>
where L: UpperHex, R: UpperHex,



impl<O> UpperHex for I16<O>
where O: ByteOrder,



impl<O> UpperHex for I32<O>
where O: ByteOrder,



impl<O> UpperHex for I64<O>
where O: ByteOrder,



impl<O> UpperHex for I128<O>
where O: ByteOrder,



impl<O> UpperHex for Isize<O>
where O: ByteOrder,



impl<O> UpperHex for U16<O>
where O: ByteOrder,



impl<O> UpperHex for U32<O>
where O: ByteOrder,



impl<O> UpperHex for U64<O>
where O: ByteOrder,



impl<O> UpperHex for U128<O>
where O: ByteOrder,



impl<O> UpperHex for Usize<O>
where O: ByteOrder,

1.0.0 · Source

impl<T> UpperHex for &T
where T: UpperHex + ?Sized,

1.0.0 · Source

impl<T> UpperHex for &mut T
where T: UpperHex + ?Sized,

1.28.0 · Source

impl<T> UpperHex for NonZero<T>



impl<T> UpperHex for Ptr<T>
where T: ?Sized,



impl<T> UpperHex for Ptr<T>
where T: ?Sized,

1.74.0 · Source

impl<T> UpperHex for Saturating<T>
where T: UpperHex,

1.11.0 · Source

impl<T> UpperHex for Wrapping<T>
where T: UpperHex,